@@ -5,7 +5,7 @@ use utf8;
 use Kavorka;
 use Regexp::Grammars;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 my %hash;
@@ -126,7 +126,7 @@ INI::Reader::Regexp - INI Parser
 
 =head1 SYNOPSIS
 
-	If file.ini contains:
+	If ini_string contains:
 
 
 	[Settings]
@@ -166,68 +166,26 @@ INI::Reader::Regexp - INI Parser
 	#======================================================================
 
 
-	Then when your program contains:
-	my $hash = $obj->INI_parse($ini_file);
-
-
-	$hash will contain
-	{
-	  'Settings' => {
-					  'Archive' => '1',
-					  'RunStatus' => '1',
-					  'ServerName' => 'Unknown',
-					  'LogFile' => '/opt/ecs/mvuser/MV_IPTel/log/MV_IPTel.log',
-					  'Version' => '0.9 Build 4 Created July 11 2004 14:00',
-					  'StatusPort' => '6090',
-					  'DetailedLog' => '1',
-					  'StatusRefresh' => '10'
-					},
-	  'FTP' => {
-				 'SUPassword' => 'Avaya',
-				 'FTPDir' => '/opt/ecs/mvuser/MV_IPTel/data/FTPdata',
-				 'FTPPort' => '21',
-				 'FTP_TimeOut' => '5',
-				 'EnableSU' => '1',
-				 'RunFTP' => '1',
-				 'SUUserName' => 'mvuser'
-			   }
-			   'FTPDataPort' => '20',
-	};
-
-
-
 =head1 DESCRIPTION
 
-Stub documentation for INI::Reader::Regexp, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
+	use strict;
+	use warnings;
+	use utf8;
+    use INI::Reader::Regexp;
 
-Blah blah blah.
+    my $ini_parser = INI::Reader::Regexp->new();
+	my $hash = $ini_parser->INI_parse($ini_string);
 
-=head2 EXPORT
+	print $hash->{Settings}->{ServerName};
 
-None by default.
-
-
-
-=head1 SEE ALSO
-
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
 
 =head1 AUTHOR
 
-pc, E<lt>pc@E<gt>
+Rajkumar Reddy
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2021 by pc
+Copyright (C) 2021 by Rajkumar Reddy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.30.0 or,
